<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="hu">
<context>
    <name>ClientSSL</name>
    <message>
        <location filename="../clientssl.cpp" line="248"/>
        <source>Connected to host</source>
        <translation type="obsolete">Csatlakoztatva a hoszthoz</translation>
    </message>
    <message>
        <location filename="../clientssl.cpp" line="264"/>
        <source>Socket error</source>
        <translation type="obsolete">Foglalathiba</translation>
    </message>
    <message>
        <location filename="../clientssl.cpp" line="277"/>
        <source>Connection closed</source>
        <translation type="obsolete">Kapcsolat lezárva</translation>
    </message>
    <message>
        <location filename="../clientssl.cpp" line="143"/>
        <source>Host not found !</source>
        <translation type="obsolete">Hoszt nem található !</translation>
    </message>
    <message>
        <location filename="../clientssl.cpp" line="118"/>
        <source>Connection in progress on %1</source>
        <translation type="obsolete">Csatlakozás folyamatban %1</translation>
    </message>
</context>
<context>
    <name>ClientSocket</name>
    <message>
        <location filename="../clientsocket.cpp" line="434"/>
        <source>Properties</source>
        <translation type="obsolete">Tulajdonságok</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="408"/>
        <source>Send out message to all users</source>
        <translation type="obsolete">Üzenet küldése minden felhasználónak</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="418"/>
        <source>Send out message to</source>
        <translation type="obsolete">Üzenet küldése</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="428"/>
        <source>Disconnect user</source>
        <translation type="obsolete">Felhasználó lecsatlakoztatása</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="562"/>
        <source>&amp;Yes</source>
        <translation type="obsolete">&amp;Igen</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="562"/>
        <source>&amp;No</source>
        <translation type="obsolete">&amp;Nem</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="499"/>
        <source>Message to send</source>
        <translation type="obsolete">Üzenet küldése</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="527"/>
        <source>Message to send to %1:</source>
        <translation type="obsolete">Üzenet küldése ide : %1:</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="561"/>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation type="obsolete">Valóban le akarja csatlakoztatni a következő felhasználót: %1 ?</translation>
    </message>
    <message>
        <location filename="../clientsocket.cpp" line="153"/>
        <source>Host not found !</source>
        <translation type="obsolete">Hoszt nem található !</translation>
    </message>
</context>
<context>
    <name>LogForm</name>
    <message>
        <location filename="../log.cpp" line="82"/>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <location filename="../log.cpp" line="82"/>
        <source>Machine</source>
        <translation>Gép</translation>
    </message>
    <message>
        <location filename="../log.cpp" line="82"/>
        <source>User</source>
        <translation>Felhasználó</translation>
    </message>
    <message>
        <location filename="../log.cpp" line="82"/>
        <source>Service</source>
        <translation>Szolgáltatás</translation>
    </message>
    <message>
        <location filename="../log.cpp" line="108"/>
        <source>Open File</source>
        <translation>Fájl megnyitása</translation>
    </message>
    <message>
        <location filename="../log.cpp" line="82"/>
        <source>Type</source>
        <translation>Tipus</translation>
    </message>
</context>
<context>
    <name>MainWindows</name>
    <message>
        <location filename="../mainwindows.cpp" line="68"/>
        <source>QtSmbstatus Client</source>
        <translation type="obsolete">QtSmbstatus kliens</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="86"/>
        <source>Show CIFS/SMB activities</source>
        <translation>CIFS/SMB tevékenységek mutatása</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="88"/>
        <source>Configure</source>
        <translation>Beállítás</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="172"/>
        <source>Minimize</source>
        <translation>Minimalizálás</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="93"/>
        <source>Quit</source>
        <translation>Kilépés</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="170"/>
        <source>Restore</source>
        <translation>Helyreállítás</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="245"/>
        <source>Thanks to:</source>
        <translation>Köszönetnyilvánítás:</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="259"/>
        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="291"/>
        <source>Find text</source>
        <translation>Szöveg kereése</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="342"/>
        <source>Text not found.</source>
        <translation>Szöveg nem található.</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="380"/>
        <source>User %1 has opened share %2 (%3)</source>
        <translation>%1 felhasználó megnyitotta a(z) %2 (%3) megosztást</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="381"/>
        <source>User %1 has opened file %2 (%3)</source>
        <translation>%1 felhasználó megnyitotta a(z) %2 (%3) fájlt</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="392"/>
        <source>CIFS/SMB activities</source>
        <translation>CIFS/SMB tevékenységek</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="504"/>
        <source>Message to send</source>
        <translation>Üzenet küldése</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="532"/>
        <source>Message to send to %1:</source>
        <translation>Üzenet küldése ide : %1:</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="563"/>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation>Valóban le akarja csatlakoztatni a következő felhasználót: %1 ?</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="564"/>
        <source>&amp;Yes</source>
        <translation>&amp;Igen</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="564"/>
        <source>&amp;No</source>
        <translation>&amp;Nem</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="618"/>
        <source>Properties</source>
        <translation>Tulajdonságok</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="592"/>
        <source>Send out message to all users</source>
        <translation>Üzenet küldése minden felhasználónak</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="602"/>
        <source>Send out message to</source>
        <translation>Üzenet küldése</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="612"/>
        <source>Disconnect user</source>
        <translation>Felhasználó lecsatlakoztatása</translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="720"/>
        <source>Update is available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="723"/>
        <source>A new release of %1 is available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindows.cpp" line="725"/>
        <source>You can download it here: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <location filename="../configure.ui" line="19"/>
        <source>Configure</source>
        <translation>Beállítás</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="325"/>
        <source>Autoconnect</source>
        <translation>Autocsatlakozás</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="332"/>
        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Alapértelmezett hoszt cím:&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="309"/>
        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Alapértelmezett felhasználónév:&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="355"/>
        <source>Host Address</source>
        <translation>Hoszt cím</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="62"/>
        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
        <translation>&lt;p align=&quot;right&quot;&gt;Időtartam:&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="238"/>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="215"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="345"/>
        <source>Username (default :  username = root)</source>
        <translation>Felhasználónév (alapértelmezett : felhasználónév = root)</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="190"/>
        <source>Log SMB/CIFS activities</source>
        <translation>SMB/CIFS tevékenységek tárolása</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="180"/>
        <source>Status notification messages</source>
        <translation>Állapot figyelmeztető üzenetek</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="107"/>
        <source>Notifications and log</source>
        <translation>Figyelmeztetések és log</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="125"/>
        <source>Limit log:</source>
        <translation>Log korlát:</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="154"/>
        <source>days</source>
        <translation>napok</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="170"/>
        <source>Iconize QtSmbstatus in system tray</source>
        <translation>QtSmbstatus ikon méretűre a rendszertálcára.</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="31"/>
        <source>Smbstatus</source>
        <translation>Smbstatus</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="75"/>
        <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
        <translation>Az smbstatus lekérdezések időtartama között másodpercben. (időtartam &gt; 2)</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="88"/>
        <source>Show hidden shares (share$)</source>
        <translation>Mutasd a rejtett megosztásokat (share$)</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="91"/>
        <source>Show hidden shares</source>
        <translation>A rejtett megosztások megjelenítése</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="291"/>
        <source>Connection</source>
        <translation>Kapcsolat</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="322"/>
        <source>Autoconnect on qtsmbstatus startup</source>
        <translation>Automatikus kapcsolódás a QtSmbstatus indulásakor</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="177"/>
        <source>Show activities in &quot;balloon messages&quot;</source>
        <translation>Tevékenységek mutatása &quot;buborék-üzenetekben&quot;</translation>
    </message>
    <message>
        <location filename="../configure.ui" line="256"/>
        <source>Misc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="265"/>
        <source>Automatically Check for updates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configure.ui" line="272"/>
        <source>A new release is available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>form_smbstatus</name>
    <message>
        <location filename="../form_smbstatus.ui" line="13"/>
        <source>qtsmbstatus</source>
        <translation>qtsmbstatus</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="167"/>
        <source>&amp;Help</source>
        <translation>&amp;Súgó</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="188"/>
        <source>&amp;About QtSmbstatus</source>
        <translation>QtSmbst&amp;atus névjegy</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="205"/>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt névjegy</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="117"/>
        <source>Connect/Disconnect</source>
        <translation>Kapcsolódás/Bontás</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="61"/>
        <source>Host:</source>
        <translation>Kiszolgáló:</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="223"/>
        <source>&amp;Configure client</source>
        <translation>Kliens &amp;beállítása</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="159"/>
        <source>&amp;Search</source>
        <translation>Keresé&amp;s</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="234"/>
        <source>&amp;Machine</source>
        <translation>&amp;Gép</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="245"/>
        <source>&amp;User</source>
        <translation>Fel&amp;használó</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="256"/>
        <source>Share &amp;open</source>
        <translation>Megosztás &amp;megnyitása</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="267"/>
        <source>&amp;Locked file</source>
        <translation>&amp;Zárolt fájlok</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="278"/>
        <source>&amp;Next</source>
        <translation>&amp;Következő</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="284"/>
        <source>F3</source>
        <translation>F3</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="292"/>
        <source>&amp;Find text</source>
        <translation>&amp;Szöveg keresése</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="298"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="148"/>
        <source>&amp;File</source>
        <translation>&amp;Fájl</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="208"/>
        <source>About Qt</source>
        <translation>Qt névjegy</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="226"/>
        <source>Configure QtSmbstatus client</source>
        <translation>QtSmbstatus kliens beállítása</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="237"/>
        <source>Search machine</source>
        <translation>Gép keresése</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="248"/>
        <source>Search user</source>
        <translation>Felhasználó keresése</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="259"/>
        <source>Search share open</source>
        <translation>Megosztás nyitás keresése</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="270"/>
        <source>Search file open</source>
        <translation>Fájl nyitás keresése</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="281"/>
        <source>Next</source>
        <translation>Következő</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="295"/>
        <source>Find text</source>
        <translation>Szöveg kereése</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="307"/>
        <source>&amp;Quit</source>
        <translation>&amp;Kilépés</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="310"/>
        <source>Quit QtSmbstatus</source>
        <translation>Kilépés a QtSmbstatus -ból</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="324"/>
        <source>Co&amp;nnect</source>
        <translation>Cs&amp;atlakozás</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="315"/>
        <source>&amp;Show CIFS/SMB activities</source>
        <translation>CIFS/SMB tevékenységek &amp;mutatása</translation>
    </message>
    <message>
        <location filename="../form_smbstatus.ui" line="191"/>
        <source>About QtSmbstatus</source>
        <translation>QtSmbstatus névjegy</translation>
    </message>
</context>
<context>
    <name>logform</name>
    <message>
        <location filename="../log.ui" line="13"/>
        <source>View Activities</source>
        <translation>Tevékenységek megtekintése</translation>
    </message>
    <message>
        <location filename="../log.ui" line="124"/>
        <source>View/hide shares</source>
        <translation>Megosztások megjelenítése/elrejtése</translation>
    </message>
    <message>
        <location filename="../log.ui" line="156"/>
        <source>View/hide files</source>
        <translation>Fájlok megjelenítése/elrejtése</translation>
    </message>
    <message>
        <location filename="../log.ui" line="196"/>
        <source>Filter:</source>
        <translation>Szűrő:</translation>
    </message>
    <message>
        <location filename="../log.ui" line="41"/>
        <source>Clear</source>
        <translation>Tisztítás</translation>
    </message>
    <message>
        <location filename="../log.ui" line="104"/>
        <source>Close</source>
        <translation>Bezár</translation>
    </message>
    <message>
        <location filename="../log.ui" line="70"/>
        <source>Save log</source>
        <translation>Napló mentése</translation>
    </message>
</context>
<context>
    <name>login_dialog</name>
    <message>
        <location filename="../login_dialog.ui" line="120"/>
        <source>login</source>
        <translation>bejelentkezés</translation>
    </message>
    <message>
        <location filename="../login_dialog.ui" line="149"/>
        <source>exit</source>
        <translation>kilépés</translation>
    </message>
    <message>
        <location filename="../login_dialog.ui" line="27"/>
        <source>Username</source>
        <translation>Felhasználónév</translation>
    </message>
    <message>
        <location filename="../login_dialog.ui" line="49"/>
        <source>root</source>
        <translation>root</translation>
    </message>
    <message>
        <location filename="../login_dialog.ui" line="62"/>
        <source>Password</source>
        <translation>Jelszó</translation>
    </message>
    <message>
        <location filename="../login_dialog.ui" line="13"/>
        <source>Connect to qtsmbstatus server</source>
        <translation>Csatlakozás a qtsmbstatus szerverhez</translation>
    </message>
</context>
<context>
    <name>main_windows</name>
    <message>
        <location filename="../main_windows.cpp" line="488"/>
        <source>Search share</source>
        <translation type="obsolete">Megosztás keresése</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="497"/>
        <source>Search locked file</source>
        <translation type="obsolete">Zárolt fájl keresése</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="627"/>
        <source>Text not found.</source>
        <translation type="obsolete">Szöveg nem található.</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="70"/>
        <source>QtSmbstatus Client</source>
        <translation type="obsolete">QtSmbstatus kliens</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="310"/>
        <source>Connect</source>
        <translation>Kapcsolat</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="177"/>
        <source>Minimize</source>
        <translation type="obsolete">Minimalizálás</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="82"/>
        <source>Quit</source>
        <translation type="obsolete">Kilépés</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="175"/>
        <source>Restore</source>
        <translation type="obsolete">Helyreállítás</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="305"/>
        <source>Disconnect</source>
        <translation>Kapcsolat bontása</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="665"/>
        <source>User %1 has opened share %2 (%3)</source>
        <translation type="obsolete">%1 felhasználó megnyitotta a(z) %2 (%3) megosztást</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="666"/>
        <source>User %1 has opened file %2 (%3)</source>
        <translation type="obsolete">%1 felhasználó megnyitotta a(z) %2 (%3) fájlt</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="75"/>
        <source>Show CIFS/SMB activities</source>
        <translation type="obsolete">CIFS/SMB tevékenységek mutatása</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="91"/>
        <source>Impossible to know samba version</source>
        <translation type="obsolete">Samba verzió lekérdezése lehetetlen</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="356"/>
        <source>Invalid login or password !</source>
        <translation>Érvénytelen felhasználónév vagy jelszó !</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="677"/>
        <source>CIFS/SMB activities</source>
        <translation type="obsolete">CIFS/SMB tevékenységek</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="519"/>
        <source>Thanks to:</source>
        <translation type="obsolete">Köszönetnyilvánítás:</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="77"/>
        <source>Configure</source>
        <translation type="obsolete">Beállítás</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="576"/>
        <source>Find text</source>
        <translation type="obsolete">Szöveg kereése</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="469"/>
        <source>Search machine</source>
        <translation type="obsolete">Gép keresése</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="479"/>
        <source>Search user</source>
        <translation type="obsolete">Felhasználó keresése</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="198"/>
        <source>Connection in progress on %1</source>
        <translation>Csatlakozás folyamatban %1</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="223"/>
        <source>Connected to host</source>
        <translation>Csatlakoztatva a hoszthoz</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="241"/>
        <source>Connection closed</source>
        <translation>Kapcsolat lezárva</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="965"/>
        <source>Properties</source>
        <translation type="obsolete">Tulajdonságok</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="939"/>
        <source>Send out message to all users</source>
        <translation type="obsolete">Üzenet küldése minden felhasználónak</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="949"/>
        <source>Send out message to</source>
        <translation type="obsolete">Üzenet küldése</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="959"/>
        <source>Disconnect user</source>
        <translation type="obsolete">Felhasználó lecsatlakoztatása</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="1031"/>
        <source>Message to send</source>
        <translation type="obsolete">Üzenet küldése</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="1057"/>
        <source>Message to send to %1:</source>
        <translation type="obsolete">Üzenet küldése ide : %1:</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="1089"/>
        <source>Do you really want to disconnect user %1 ?</source>
        <translation type="obsolete">Valóban le akarja csatlakoztatni a következő felhasználót: %1 ?</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="1090"/>
        <source>&amp;Yes</source>
        <translation type="obsolete">&amp;Igen</translation>
    </message>
    <message>
        <location filename="../main_windows.cpp" line="1090"/>
        <source>&amp;No</source>
        <translation type="obsolete">&amp;Nem</translation>
    </message>
</context>
</TS>
